@@ -4,4 +4,4 @@ mod config;
 
 pub use audio_stream::AudioStream;
 pub use audio_stream::Event;
-pub use config::Config;
+pub use config::{Config, VolumeNormalisation};
